@@ -4,12 +4,13 @@ from typing import Any, Dict, List, Optional, Union, cast
 
 import yaml
 
-from hpcrocket.core.environmentpreparation import CopyInstruction
+from hpcrocket.core.filesystem.progressive import CopyInstruction
 from hpcrocket.core.filesystem import Filesystem
 from hpcrocket.core.launchoptions import (
+    FinalizeOptions,
     LaunchOptions,
     Options,
-    SimpleJobOptions,
+    ImmediateCommandOptions,
     WatchOptions,
 )
 from hpcrocket.ssh.connectiondata import ConnectionData
@@ -23,7 +24,11 @@ def parse_cli_args(args: List[str], filesystem: Filesystem) -> Options:
 
 def _create_options(config: argparse.Namespace, filesystem: Filesystem) -> Options:
     yaml_config = _parse_yaml(config.configfile, filesystem)
-    option_builders = {"launch": _build_launch_options, "watch": _build_watch_options}
+    option_builders = {
+        "launch": _build_launch_options,
+        "finalize": _build_finalize_options,
+        "watch": _build_watch_options,
+    }
 
     builder = option_builders.get(config.command, _build_simple_job_options)
 
@@ -40,6 +45,17 @@ def _build_launch_options(
         sbatch=os.path.expandvars(sbatch),
         watch=watch,
         copy_files=_collect_copy_instructions(yaml_config.get("copy", [])),
+        clean_files=_clean_instructions(yaml_config.get("clean", [])),
+        collect_files=_collect_copy_instructions(yaml_config.get("collect", [])),
+        continue_if_job_fails=yaml_config.get("continue_if_job_fails", False),
+        **_connection_dict(yaml_config)  # type: ignore
+    )
+
+
+def _build_finalize_options(
+    config: argparse.Namespace, yaml_config: Dict[str, Any]
+) -> Options:
+    return FinalizeOptions(
         clean_files=_clean_instructions(yaml_config.get("clean", [])),
         collect_files=_collect_copy_instructions(yaml_config.get("collect", [])),
         **_connection_dict(yaml_config)  # type: ignore
@@ -69,9 +85,9 @@ def _build_simple_job_options(
     jobid = cast(str, config.jobid)
     command = cast(str, config.command)
 
-    return SimpleJobOptions(
+    return ImmediateCommandOptions(
         jobid=jobid,
-        action=SimpleJobOptions.Action[command],
+        action=ImmediateCommandOptions.Action[command],
         **_connection_dict(yaml_config)  # type: ignore
     )
 
@@ -88,6 +104,7 @@ def _setup_parser() -> argparse.ArgumentParser:
     subparsers = parser.add_subparsers(dest="command")
 
     _setup_launch_parser(subparsers)
+    _setup_finalize_parser(subparsers)
     _setup_status_parser(subparsers)
     _setup_watch_parser(subparsers)
     _setup_cancel_parser(subparsers)
@@ -103,6 +120,17 @@ def _setup_launch_parser(
     parser.add_argument("--watch", default=False, dest="watch", action="store_true")
 
 
+def _setup_finalize_parser(
+    subparsers: "argparse._SubParsersAction[argparse.ArgumentParser]",
+) -> None:
+    parser = subparsers.add_parser(
+        "finalize", help="Run collect and clean instructions"
+    )
+    parser.add_argument(
+        "configfile", type=str, help="A config file containing the connection data"
+    )
+
+
 def _setup_status_parser(
     subparsers: "argparse._SubParsersAction[argparse.ArgumentParser]",
 ) -> None:
