@@ -2,17 +2,16 @@ from dataclasses import dataclass, field
 from enum import Enum, auto
 from typing import List, Union
 
-from hpcrocket.core.environmentpreparation import CopyInstruction
+from hpcrocket.core.filesystem.progressive import CopyInstruction
 from hpcrocket.ssh.connectiondata import ConnectionData
 
 
-Options = Union['LaunchOptions', 'SimpleJobOptions', 'WatchOptions']
-JobBasedOptions = Union['SimpleJobOptions', 'WatchOptions']
+Options = Union["LaunchOptions", "ImmediateCommandOptions", "WatchOptions", "FinalizeOptions"]
+JobBasedOptions = Union["ImmediateCommandOptions", "WatchOptions"]
 
 
 @dataclass
-class SimpleJobOptions:
-
+class ImmediateCommandOptions:
     class Action(Enum):
         status = auto()
         cancel = auto()
@@ -33,6 +32,7 @@ class LaunchOptions:
     collect_files: List[CopyInstruction] = field(default_factory=lambda: [])
     poll_interval: int = 5
     watch: bool = False
+    continue_if_job_fails: bool = False
 
 
 @dataclass
@@ -41,3 +41,11 @@ class WatchOptions:
     connection: ConnectionData
     proxyjumps: List[ConnectionData] = field(default_factory=lambda: [])
     poll_interval: int = 5
+
+
+@dataclass
+class FinalizeOptions:
+    connection: ConnectionData
+    proxyjumps: List[ConnectionData] = field(default_factory=lambda: [])
+    collect_files: List[CopyInstruction] = field(default_factory=lambda: [])
+    clean_files: List[str] = field(default_factory=lambda: [])
