@@ -1,10 +1,9 @@
-from typing import List, Optional, cast
+from typing import List, Optional, Tuple, cast
 
-from hpcrocket.core.environmentpreparation import (
+from hpcrocket.core.filesystem.progressive import (
     CopyInstruction,
-    EnvironmentPreparation,
-    EnvironmentCleaner,
-    EnvironmentCollector,
+    progressive_copy,
+    progressive_clean,
 )
 from hpcrocket.core.errors import get_error_message
 from hpcrocket.core.filesystem import FilesystemFactory
@@ -28,6 +27,11 @@ class NoJobLaunchedError(Exception):
     pass
 
 
+def _log_errors(errors: List[Exception], ui: UI) -> None:
+    for error in errors:
+        ui.error(get_error_message(error))
+
+
 class LaunchStage:
     """
     Launches a batch job.
@@ -39,6 +43,9 @@ class LaunchStage:
         self._batch_script = batch_script
         self._batch_job: Optional[SlurmBatchJob] = None
 
+    def allowed_to_fail(self) -> bool:
+        return False
+
     def __call__(self, ui: UI) -> bool:
         self._batch_job = self._controller.submit(self._batch_script)
         ui.launch(f"Launched job {self._batch_job.jobid}")
@@ -72,6 +79,7 @@ class WatchStage:
             Returns:
                 SlurmBatchJob
             """
+            ...
 
         def cancel(self, ui: UI) -> None:
             """
@@ -80,15 +88,24 @@ class WatchStage:
             Args:
                 ui (UI): The UI instance WatchStage was called with
             """
+            ...
 
     def __init__(
-        self, batch_job_provider: BatchJobProvider, poll_interval: int
+        self,
+        batch_job_provider: BatchJobProvider,
+        poll_interval: int,
+        allowed_to_fail: bool = False,
     ) -> None:
         self._poll_interval = poll_interval
         self._provider = batch_job_provider
         self._watcher: Optional[JobWatcher] = None
         self._job_status: Optional[SlurmJobStatus] = None
 
+        self._allowed_to_fail = allowed_to_fail
+
+    def allowed_to_fail(self) -> bool:
+        return self._allowed_to_fail
+
     def __call__(self, ui: UI) -> bool:
         batch_job = self._provider.get_batch_job()
         self._watcher = batch_job.get_watcher()
@@ -119,42 +136,43 @@ class PrepareStage:
         filesystem_factory: FilesystemFactory,
         copy_instructions: List[CopyInstruction],
     ) -> None:
-        self._factory = filesystem_factory
+        self._local_fs = filesystem_factory.create_local_filesystem()
+        self._remote_fs = filesystem_factory.create_ssh_filesystem()
         self._files = copy_instructions
 
+    def allowed_to_fail(self) -> bool:
+        return False
+
     def __call__(self, ui: UI) -> bool:
-        env_prep = self._create_env_prep(ui)
-        return self._try_prepare(env_prep, ui)
+        ui.info("Copying files...")
+        copied_files, errors = self._try_copy_files()
+
+        if errors:
+            _log_errors(errors, ui)
+            self._do_rollback(copied_files, ui)
+            return False
+
+        ui.success("Done")
+        return True
 
     def cancel(self, ui: UI) -> None:
         pass
 
-    def _try_prepare(self, env_prep: EnvironmentPreparation, ui: UI) -> bool:
-        try:
-            ui.info("Copying files...")
-            env_prep.prepare()
-            ui.success("Done")
-        except (FileExistsError, FileNotFoundError) as err:
-            self._do_rollback(env_prep, err, ui)
-            return False
+    def _try_copy_files(self) -> Tuple[List[str], List[Exception]]:
+        copied_files: List[str] = []
+        errors: List[Exception] = []
+        for cr in progressive_copy(self._local_fs, self._remote_fs, self._files):
+            copied_files.extend(cr.copied_files)
+            if cr.errors:
+                errors.extend(cr.errors)
+                break
 
-        return True
+        return copied_files, errors
 
-    def _create_env_prep(self, ui: UI) -> EnvironmentPreparation:
-        env_prep = EnvironmentPreparation(
-            self._factory.create_local_filesystem(),
-            self._factory.create_ssh_filesystem(),
-            self._files,
-            ui,
-        )
-
-        return env_prep
-
-    @staticmethod
-    def _do_rollback(env_prep: EnvironmentPreparation, err: Exception, ui: UI) -> None:
-        ui.error(get_error_message(err))
+    def _do_rollback(self, files: List[str], ui: UI) -> None:
         ui.info("Performing rollback")
-        env_prep.rollback()
+        errors = list(progressive_clean(self._remote_fs, files))
+        _log_errors(errors, ui)
         ui.success("Done")
 
 
@@ -169,10 +187,14 @@ class FinalizeStage:
         collect_instructions: List[CopyInstruction],
         clean_instructions: List[str],
     ) -> None:
-        self._factory = filesystem_factory
-        self._collect = collect_instructions
+        self._local_fs = filesystem_factory.create_local_filesystem()
+        self._remote_fs = filesystem_factory.create_ssh_filesystem()
+        self._files = collect_instructions
         self._clean = clean_instructions
 
+    def allowed_to_fail(self) -> bool:
+        return False
+
     def __call__(self, ui: UI) -> bool:
         self._collect_files(ui)
         self._clean_files(ui)
@@ -180,22 +202,18 @@ class FinalizeStage:
         return True
 
     def _collect_files(self, ui: UI) -> None:
-        collector = EnvironmentCollector(
-            self._factory.create_ssh_filesystem(),
-            self._factory.create_local_filesystem(),
-            self._collect,
-            ui,
-        )
         ui.info("Collecting files...")
-        collector.collect()
+        for cr in progressive_copy(
+            self._remote_fs, self._local_fs, self._files, abort_on_error=False
+        ):
+            _log_errors(cr.errors, ui)
+
         ui.success("Done")
 
     def _clean_files(self, ui: UI) -> None:
-        cleaner = EnvironmentCleaner(
-            self._factory.create_ssh_filesystem(), self._clean, ui
-        )
         ui.info("Cleaning files...")
-        cleaner.clean()
+        errors = list(progressive_clean(self._remote_fs, self._clean))
+        _log_errors(errors, ui)
         ui.success("Done")
 
     def cancel(self, ui: UI) -> None:
@@ -211,6 +229,9 @@ class StatusStage:
         self._controller = controller
         self._jobid = jobid
 
+    def allowed_to_fail(self) -> bool:
+        return False
+
     def __call__(self, ui: UI) -> bool:
         ui.update(self._controller.poll_status(self._jobid))
         return True
@@ -228,6 +249,9 @@ class CancelStage:
         self._controller = controller
         self._jobid = jobid
 
+    def allowed_to_fail(self) -> bool:
+        return False
+
     def __call__(self, ui: UI) -> bool:
         self._controller.cancel(self._jobid)
         return True
