@@ -1,14 +1,30 @@
 import os
-from typing import List, Optional, Tuple
+from typing import List, Tuple
 import unittest
-from hpcrocket.core.filesystem import FilesystemFactory
-from hpcrocket.core.launchoptions import LaunchOptions
-from hpcrocket.ui import UI
+from test.application import make_application
+from test.application.assertions import (
+    assert_does_not_exist_locally,
+    assert_does_not_exist_on_remote,
+    assert_exists_locally,
+    assert_exists_on_remote,
+)
 from test.application.executor_filesystem_callorder import (
     CallOrderVerification,
     VerifierReturningFilesystemFactory,
 )
-from test.application.launchoptions import launch_options, main_connection
+from test.application.optionbuilders import (
+    COLLECTED_FILE,
+    GLOB_PATTERN,
+    LOCAL_DIR,
+    LOCAL_FILE,
+    NON_MATCHING_FILE,
+    REMOTE_DIR,
+    REMOTE_FILE,
+    launch_options,
+    launch_options_copy_collect_clean,
+    launch_options_with_copy,
+    main_connection,
+)
 from test.slurmoutput import completed_slurm_job
 from test.testdoubles.executor import (
     failed_slurm_job_command_stub,
@@ -17,67 +33,26 @@ from test.testdoubles.executor import (
     successful_slurm_job_command_stub,
 )
 from test.testdoubles.filesystem import (
-    DummyFilesystemFactory,
     MemoryFilesystemFactoryStub,
     MemoryFilesystemFake,
 )
 from unittest.mock import Mock
 
 from hpcrocket.core.application import Application
-from hpcrocket.core.environmentpreparation import CopyInstruction
-from hpcrocket.core.executor import CommandExecutor, RunningCommand
+from hpcrocket.core.filesystem.progressive import CopyInstruction
+from hpcrocket.core.executor import RunningCommand
 from hpcrocket.ssh.errors import SSHError
 
-LOCAL_FILE = "myfile.txt"
-LOCAL_DIR = "localdir/"
-
-REMOTE_FILE = "mycopy.txt"
-REMOTE_DIR = "remotedir/"
-
-COLLECTED_FILE = "mycollect.txt"
-
-GLOB_PATTERN = "*.txt"
-NON_MATCHING_FILE = "NON_MATCHING_FILE.gif"
-
 
 class ConnectionFailingCommandExecutor(LoggingCommandExecutorSpy):
     def connect(self) -> None:
         raise SSHError(main_connection().hostname)
 
     def close(self) -> None:
-        pass
+        ...
 
     def exec_command(self, cmd: str) -> RunningCommand:
-        pass
-
-
-def launch_options_with_copy() -> LaunchOptions:
-    return launch_options(copy=[CopyInstruction(LOCAL_FILE, REMOTE_FILE)])
-
-
-def launch_options_with_collect() -> LaunchOptions:
-    return launch_options(
-        collect=[CopyInstruction(REMOTE_FILE, COLLECTED_FILE)],
-        watch=True,
-    )
-
-
-def launch_options_with_clean() -> LaunchOptions:
-    return launch_options(clean=[REMOTE_FILE], watch=True)
-
-
-def launch_options_copy_collect() -> LaunchOptions:
-    return launch_options(
-        copy=[CopyInstruction(LOCAL_FILE, REMOTE_FILE)],
-        collect=[CopyInstruction(REMOTE_FILE, COLLECTED_FILE)],
-        watch=True,
-    )
-
-
-def launch_options_copy_collect_clean() -> LaunchOptions:
-    opts = launch_options_copy_collect()
-    opts.clean_files = [REMOTE_FILE]
-    return opts
+        ...
 
 
 def memory_fs_factory_with_default_local_file() -> MemoryFilesystemFactoryStub:
@@ -86,18 +61,6 @@ def memory_fs_factory_with_default_local_file() -> MemoryFilesystemFactoryStub:
     return MemoryFilesystemFactoryStub(local_fs, remote_fs)
 
 
-def make_sut(
-    executor: Optional[CommandExecutor] = None,
-    filesystem_factory: Optional[FilesystemFactory] = None,
-    ui: Optional[UI] = None,
-) -> Application:
-    return Application(
-        executor or SlurmJobExecutorSpy(),
-        filesystem_factory or DummyFilesystemFactory(),
-        ui or Mock(),
-    )
-
-
 def make_sut_with_call_order_verification(
     expected_calls: List[str],
 ) -> Tuple[Application, CallOrderVerification]:
@@ -107,31 +70,11 @@ def make_sut_with_call_order_verification(
     return sut, verifier
 
 
-def assert_exists_locally(fs_factory: MemoryFilesystemFactoryStub, file: str) -> None:
-    assert fs_factory.local_filesystem.exists(file)
-
-
-def assert_does_not_exist_locally(
-    fs_factory: MemoryFilesystemFactoryStub, file: str
-) -> None:
-    assert not fs_factory.local_filesystem.exists(file)
-
-
-def assert_exists_on_remote(fs_factory: MemoryFilesystemFactoryStub, file: str) -> None:
-    assert fs_factory.ssh_filesystem.exists(file)
-
-
-def assert_does_not_exist_on_remote(
-    fs_factory: MemoryFilesystemFactoryStub, file: str
-) -> None:
-    assert not fs_factory.ssh_filesystem.exists(file)
-
-
 class Application_With_Launch_Options(unittest.TestCase):
     def setUp(self) -> None:
         self.executor = SlurmJobExecutorSpy()
         self.ui_spy = Mock()
-        self.sut = make_sut(self.executor, ui=self.ui_spy)
+        self.sut = make_application(self.executor, ui=self.ui_spy)
 
     def test__when_running__it_runs_sbatch_with_executor(self) -> None:
         self.sut.run(launch_options())
@@ -161,7 +104,7 @@ class Application_With_Launch_Options(unittest.TestCase):
         self,
     ) -> None:
         executor = ConnectionFailingCommandExecutor()
-        self.sut = make_sut(executor, ui=self.ui_spy)
+        self.sut = make_application(executor, ui=self.ui_spy)
 
         actual = self.sut.run(launch_options(watch=True))
 
@@ -179,7 +122,7 @@ class Application_With_Launch_Options(unittest.TestCase):
 class Application_With_Options_To_Copy(unittest.TestCase):
     def setUp(self) -> None:
         self.fs_factory = MemoryFilesystemFactoryStub()
-        self.sut = make_sut(filesystem_factory=self.fs_factory)
+        self.sut = make_application(filesystem_factory=self.fs_factory)
 
     def test__when_running__copies_files_to_remote(self) -> None:
         self.fs_factory.create_local_files(LOCAL_FILE)
@@ -237,72 +180,23 @@ class Application_With_Options_To_Copy(unittest.TestCase):
 
         assert_does_not_exist_on_remote(self.fs_factory, LOCAL_FILE)
 
-
-class Application_With_Options_To_Collect(unittest.TestCase):
-    def setUp(self) -> None:
-        self.fs_factory = MemoryFilesystemFactoryStub()
-        self.sut = make_sut(filesystem_factory=self.fs_factory)
-
-    def test__when_running__it_collects_files_from_remote(self) -> None:
-        options = launch_options_with_collect()
-        self.fs_factory.create_remote_files(REMOTE_FILE)
-
-        self.sut.run(options)
-
-        assert_exists_locally(self.fs_factory, COLLECTED_FILE)
-
-    def test__with_globbing__when_running__collects_only_matching_files(self) -> None:
-        options = launch_options(watch=True)
-        options.collect_files = [CopyInstruction("*.txt", "store_dir")]
-        self.fs_factory.create_remote_files(REMOTE_FILE, NON_MATCHING_FILE)
-
-        self.sut.run(options)
-
-        assert_exists_locally(self.fs_factory, f"store_dir/{REMOTE_FILE}")
-        assert_does_not_exist_locally(self.fs_factory, f"store_dir/{NON_MATCHING_FILE}")
-
-    def test__with_globbing__but_file_exists_locally__when_running__still_collects_other_files(
+    def test__with_trailing_glob__when_running__copies_entire_subtree(
         self,
     ) -> None:
-        options = launch_options(watch=True)
-        existing_file = "existing.txt"
-        options.collect_files = [CopyInstruction("*.txt", "store_dir")]
-        self.fs_factory.create_remote_files(existing_file, REMOTE_FILE)
-        self.fs_factory.create_local_files(f"store_dir/{existing_file}")
+        self.fs_factory.create_local_files("dir/first.txt", "dir/subdir/second.txt")
+        options = launch_options(copy=[CopyInstruction("dir/*", "target")])
 
         self.sut.run(options)
 
-        assert_exists_locally(self.fs_factory, f"store_dir/{REMOTE_FILE}")
-
-
-class Application_With_Options_To_Clean(unittest.TestCase):
-    def setUp(self) -> None:
-        self.fs_factory = MemoryFilesystemFactoryStub()
-        self.fs_factory.create_remote_files(REMOTE_FILE)
-        self.sut = make_sut(filesystem_factory=self.fs_factory)
-        self.options = launch_options_with_clean()
-
-    def test__when_running__it_cleans_files(self) -> None:
-        self.sut.run(self.options)
-
-        assert_does_not_exist_on_remote(self.fs_factory, REMOTE_FILE)
-
-    def test__with_globbing__when_running__cleans_only_matching_files(self) -> None:
-        non_matching_file = "NON_MATCHING_FILE.gif"
-        self.fs_factory.create_remote_files(REMOTE_FILE, non_matching_file)
-        self.options.clean_files = ["*.txt"]
-
-        self.sut.run(self.options)
-
-        assert_does_not_exist_on_remote(self.fs_factory, REMOTE_FILE)
-        assert_exists_on_remote(self.fs_factory, non_matching_file)
+        assert_exists_on_remote(self.fs_factory, "target/first.txt")
+        assert_exists_on_remote(self.fs_factory, "target/subdir/second.txt")
 
 
 class Application_With_Options_To_Copy_Collect_Clean(unittest.TestCase):
     def setUp(self) -> None:
         self.options = launch_options_copy_collect_clean()
         self.fs_factory = memory_fs_factory_with_default_local_file()
-        self.sut = make_sut(filesystem_factory=self.fs_factory)
+        self.sut = make_application(filesystem_factory=self.fs_factory)
 
     def test__when_running__copies_then_collects_then_cleans_files(self) -> None:
         self.sut.run(self.options)
@@ -346,3 +240,15 @@ class Application_With_Options_To_Copy_Collect_Clean(unittest.TestCase):
         sut.run(self.options)
 
         verify()
+
+    def test__whe_job_fails__but_allowed_to_fail__collects_and_cleans(self) -> None:
+        self.options.continue_if_job_fails = True
+        executor = SlurmJobExecutorSpy(sacct_cmd=failed_slurm_job_command_stub())
+        self.sut = make_application(
+            executor=executor, filesystem_factory=self.fs_factory
+        )
+
+        self.sut.run(self.options)
+
+        assert_exists_locally(self.fs_factory, "mycollect.txt")
+        assert_does_not_exist_on_remote(self.fs_factory, "mycopy.txt")
