@@ -14,13 +14,13 @@ def test__given_completed_job__when_polling__should_trigger_callback():
 
     sut.poll()
 
-    assert call_capture['calls'] == 1
+    assert call_capture["calls"] == 1
 
 
 def test__given_running_job__when_polling_and_job_completes_after_second_poll__should_trigger_callback_twice():
-    runner = runner_with_job_change_after_calls(calls=2,
-                                                initial_job=running_job(),
-                                                next_job=completed_job())
+    runner = runner_with_job_change_after_calls(
+        calls=2, initial_job=running_job(), next_job=completed_job()
+    )
 
     callback, call_capture = callback_and_capture()
 
@@ -28,39 +28,39 @@ def test__given_running_job__when_polling_and_job_completes_after_second_poll__s
 
     sut.poll()
 
-    assert call_capture['calls'] == 2
+    assert call_capture["calls"] == 2
 
 
 def test__given_running_job__when_polling_and_job_completes_after_third__should_trigger_callback_only_twice():
-    runner = runner_with_job_change_after_calls(calls=3,
-                                                initial_job=running_job(),
-                                                next_job=completed_job())
+    runner = runner_with_job_change_after_calls(
+        calls=3, initial_job=running_job(), next_job=completed_job()
+    )
 
     callback, call_capture = callback_and_capture()
     sut = WatcherThreadImpl(runner, callback, interval=0)
 
     sut.poll()
 
-    assert call_capture['calls'] == 2
+    assert call_capture["calls"] == 2
 
 
 def test__given_pending_job__when_polling_and_job_completes_after_second_poll__should_trigger_callback_twice():
-    runner = runner_with_job_change_after_calls(calls=2,
-                                                initial_job=pending_job(),
-                                                next_job=completed_job())
+    runner = runner_with_job_change_after_calls(
+        calls=2, initial_job=pending_job(), next_job=completed_job()
+    )
 
     callback, call_capture = callback_and_capture()
     sut = WatcherThreadImpl(runner, callback, interval=0)
 
     sut.poll()
 
-    assert call_capture['calls'] == 2
+    assert call_capture["calls"] == 2
 
 
 def test__when_stopping_then_polling__should_not_trigger_callback():
-    runner = runner_with_job_change_after_calls(calls=1,
-                                                initial_job=running_job(),
-                                                next_job=completed_job())
+    runner = runner_with_job_change_after_calls(
+        calls=1, initial_job=running_job(), next_job=completed_job()
+    )
 
     callback, call_capture = callback_and_capture()
 
@@ -69,7 +69,7 @@ def test__when_stopping_then_polling__should_not_trigger_callback():
     sut.stop()
     sut.poll()
 
-    assert call_capture['calls'] == 0
+    assert call_capture["calls"] == 0
 
 
 def test__after_polling_completed_job__is_done_should_be_true():
@@ -83,48 +83,49 @@ def test__after_polling_completed_job__is_done_should_be_true():
 
 
 def test__given_running_job__when_checking_is_done_until_completion__should_be_false_then_true():
-    runner = runner_with_job_change_after_calls(calls=2,
-                                                initial_job=running_job(),
-                                                next_job=completed_job())
+    runner = runner_with_job_change_after_calls(
+        calls=2, initial_job=running_job(), next_job=completed_job()
+    )
 
-    context = {'done': []}
+    context = {"done": []}
 
     def callback(job):
-        sut = context['sut']
-        context['done'].append(sut.is_done())
+        sut = context["sut"]
+        context["done"].append(sut.is_done())
 
     sut = WatcherThreadImpl(runner, callback, interval=0)
-    context['sut'] = sut
+    context["sut"] = sut
 
     sut.poll()
 
-    assert context['done'] == [False, True]
+    assert context["done"] == [False, True]
 
 
 def test__given_running_job__when_checking_is_done_until_canceled__should_be_false_then_true():
-    runner = runner_with_job_change_after_calls(calls=2,
-                                                initial_job=running_job(),
-                                                next_job=canceled_job())
+    runner = runner_with_job_change_after_calls(
+        calls=2, initial_job=running_job(), next_job=canceled_job()
+    )
 
-    context = {'done': []}
+    context = {"done": []}
 
     def callback(job):
-        sut = context['sut']
-        context['done'].append(sut.is_done())
+        sut = context["sut"]
+        context["done"].append(sut.is_done())
 
     sut = WatcherThreadImpl(runner, callback, interval=0)
-    context['sut'] = sut
+    context["sut"] = sut
 
     sut.poll()
 
-    assert context['done'] == [False, True]
+    assert context["done"] == [False, True]
 
 
 @pytest.mark.timeout(2)
 def test__given_running_job__when_polling__should_only_poll_in_given_interval():
     call_times = []
     poll_status = make_poll_status_with_job_change_after_calls(
-        call_count=2, next_job=completed_job())
+        call_count=2, next_job=completed_job()
+    )
 
     def timerecording_wrapper():
         call_times.append(datetime.now())
@@ -138,12 +139,14 @@ def test__given_running_job__when_polling__should_only_poll_in_given_interval():
     sut.poll()
 
     diff: timedelta = call_times[1] - call_times[0]
-    assert diff.microseconds >= .1e6
+    assert diff.microseconds >= 0.1e6
 
 
 def callback_and_capture():
-    call_capture = {'calls': 0}
-    def callback(job): call_capture['calls'] += 1
+    call_capture = {"calls": 0}
+
+    def callback(job):
+        call_capture["calls"] += 1
 
     return callback, call_capture
 
@@ -161,21 +164,26 @@ def runner_returning_job_with_state(state):
     return runner_mock
 
 
-def runner_with_job_change_after_calls(calls: int, initial_job: SlurmJobStatus, next_job: SlurmJobStatus):
+def runner_with_job_change_after_calls(
+    calls: int, initial_job: SlurmJobStatus, next_job: SlurmJobStatus
+):
     runner_mock = Mock(spec=SlurmBatchJob)
     poll_status = make_poll_status_with_job_change_after_calls(
-        calls, initial_job=initial_job, next_job=next_job)
+        calls, initial_job=initial_job, next_job=next_job
+    )
 
     runner_mock.configure_mock(poll_status=poll_status)
     return runner_mock
 
 
-def make_poll_status_with_job_change_after_calls(call_count: int, next_job: SlurmJobStatus, initial_job=None):
-    call_capture = {'calls': 0}
+def make_poll_status_with_job_change_after_calls(
+    call_count: int, next_job: SlurmJobStatus, initial_job=None
+):
+    call_capture = {"calls": 0}
 
     def poll_status():
-        calls = call_capture['calls'] + 1
-        call_capture['calls'] = calls
+        calls = call_capture["calls"] + 1
+        call_capture["calls"] = calls
         if calls == call_count:
             return next_job
 
