@@ -6,15 +6,19 @@ from fs.memoryfs import MemoryFS
 
 
 class ArbitraryArgsMemoryFS(MemoryFS):
-
     def __init__(self, *args, **kwargs) -> None:
         super().__init__()
 
 
 class OnlySubFSMemoryFS(ArbitraryArgsMemoryFS):
-
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
 
-    def opendir(self, path: Text, factory: Optional[Callable[['OnlySubFSMemoryFS', Text], fs.subfs.SubFS['OnlySubFSMemoryFS']]] = None) -> fs.subfs.SubFS['OnlySubFSMemoryFS']:
+    def opendir(
+        self,
+        path: Text,
+        factory: Optional[
+            Callable[["OnlySubFSMemoryFS", Text], fs.subfs.SubFS["OnlySubFSMemoryFS"]]
+        ] = None,
+    ) -> fs.subfs.SubFS["OnlySubFSMemoryFS"]:
         return super().opendir(path, factory=fs.subfs.SubFS)
