@@ -8,7 +8,6 @@ from hpcrocket.ssh.connectiondata import ConnectionData
 
 
 class TransportStub:
-
     def __init__(self, active: bool) -> None:
         self._active = active
 
@@ -17,7 +16,6 @@ class TransportStub:
 
 
 class ChannelStub:
-
     def __init__(self, exit_code: int = 0, exit_code_ready: bool = True):
         self._exit_code = exit_code
         self._code_ready = exit_code_ready
@@ -31,7 +29,6 @@ class ChannelStub:
 
 
 class DelayedChannelSpy(ChannelStub):
-
     def __init__(self, exit_code: int = 0, calls_until_exit: int = 0):
         super().__init__(exit_code)
         self._calls_until_done = calls_until_exit
@@ -43,7 +40,6 @@ class DelayedChannelSpy(ChannelStub):
 
 
 class ChannelFileStub:
-
     def __init__(self, lines: List[str] = None, channel: ChannelStub = None):
         self._lines = lines or []
         self._channel = channel
@@ -57,19 +53,27 @@ class ChannelFileStub:
 
 
 class CmdSpecificSSHClientStub:
-
     @classmethod
-    def successful(cls: Type['CmdSpecificSSHClientStub']):
+    def successful(cls: Type["CmdSpecificSSHClientStub"]):
         return SuccessfulSlurmCmdSSHClient()
 
-
     def __init__(self, cmd_to_channels: Dict[str, ChannelFileStub]):
         self.cmd_to_channels = cmd_to_channels
 
     def set_missing_host_key_policy(self, *args):
         pass
 
-    def connect(self, hostname, port=None, username=None, password=None, pkey=None, key_filename=None, *args, **kwargs):
+    def connect(
+        self,
+        hostname,
+        port=None,
+        username=None,
+        password=None,
+        pkey=None,
+        key_filename=None,
+        *args,
+        **kwargs,
+    ):
         pass
 
     def load_host_keys(self, filename):
@@ -88,31 +92,45 @@ class CmdSpecificSSHClientStub:
 
 
 class SuccessfulSlurmCmdSSHClient(CmdSpecificSSHClientStub):
-
     def __init__(self):
-        super().__init__({
-            "sbatch": ChannelFileStub(lines=["1234"]),
-            "sacct": ChannelFileStub(lines=get_success_lines())
-        })
+        super().__init__(
+            {
+                "sbatch": ChannelFileStub(lines=["1234"]),
+                "sacct": ChannelFileStub(lines=get_success_lines()),
+            }
+        )
 
 
 class SSHClientMock(SuccessfulSlurmCmdSSHClient):
-
-    def __init__(self, launch_options: LaunchOptions, private_keyfile_abspath: str = None):
+    def __init__(
+        self, launch_options: LaunchOptions, private_keyfile_abspath: str = None
+    ):
         super().__init__()
         self._options = launch_options
-        self._private_keyfile_abspath = private_keyfile_abspath or launch_options.connection.keyfile
+        self._private_keyfile_abspath = (
+            private_keyfile_abspath or launch_options.connection.keyfile
+        )
         self.connected = False
         self.commands: Dict[str, ChannelFileStub] = {}
 
-    def connect(self, hostname, port=None, username=None, password=None, pkey=None, key_filename=None, *args, **kwargs):
+    def connect(
+        self,
+        hostname,
+        port=None,
+        username=None,
+        password=None,
+        pkey=None,
+        key_filename=None,
+        *args,
+        **kwargs,
+    ):
         self.connected = (
-            self._options.connection.hostname == hostname and
-            self._options.connection.password == password and
-            self._options.connection.username == username and
-            self._options.connection.port == port and
-            self._options.connection.key == pkey and
-            self._private_keyfile_abspath == key_filename
+            self._options.connection.hostname == hostname
+            and self._options.connection.password == password
+            and self._options.connection.username == username
+            and self._options.connection.port == port
+            and self._options.connection.key == pkey
+            and self._private_keyfile_abspath == key_filename
         )
 
     def load_host_keys(self, filename):
@@ -131,14 +149,16 @@ class SSHClientMock(SuccessfulSlurmCmdSSHClient):
         self.connected = False
 
     def verify(self):
-        assert self.commands["sbatch"] == f"sbatch {self._options.sbatch}", \
-            "Expected: " + f"sbatch {self._options.sbatch}" + f"\nbut was: {self.commands['sbatch']}"
+        assert self.commands["sbatch"] == f"sbatch {self._options.sbatch}", (
+            "Expected: "
+            + f"sbatch {self._options.sbatch}"
+            + f"\nbut was: {self.commands['sbatch']}"
+        )
 
         assert not self.connected
 
 
 class ProxyJumpVerifyingSSHClient(SuccessfulSlurmCmdSSHClient):
-
     @dataclass
     class ChannelMock:
         kind: str
@@ -151,24 +171,37 @@ class ProxyJumpVerifyingSSHClient(SuccessfulSlurmCmdSSHClient):
         def assert_points_to(self, host: ConnectionData):
             assert self.kind == "direct-tcpip"
             assert self.dest_addr == (host.hostname, host.port)
-            assert self.src_addr == ('', 0)
+            assert self.src_addr == ("", 0)
 
     class TransportStub:
-
         def __getattr__(self, name):
             return Mock(name)
 
         def open_channel(self, *args, **kwargs):
             return ProxyJumpVerifyingSSHClient.ChannelMock(*args, **kwargs)
 
-    def __init__(self, connection: ConnectionData, proxyjumps: List[ConnectionData]) -> None:
+    def __init__(
+        self, connection: ConnectionData, proxyjumps: List[ConnectionData]
+    ) -> None:
         super().__init__()
         self.expected_path = [*proxyjumps, connection]
         self.recorded_connection_path: List[ConnectionData] = []
         self._recorded_channels: List[ProxyJumpVerifyingSSHClient.ChannelMock] = []
 
-    def connect(self, hostname, port=None, username=None, password=None, pkey=None, key_filename=None, *args, **kwargs):
-        self.recorded_connection_path.append(ConnectionData(hostname, username, password, key_filename, pkey, port))
+    def connect(
+        self,
+        hostname,
+        port=None,
+        username=None,
+        password=None,
+        pkey=None,
+        key_filename=None,
+        *args,
+        **kwargs,
+    ):
+        self.recorded_connection_path.append(
+            ConnectionData(hostname, username, password, key_filename, pkey, port)
+        )
         self._recorded_channels.append(kwargs.get("sock"))
 
     def get_transport(self):
