@@ -1,6 +1,8 @@
 from test.slurmoutput import DEFAULT_JOB_ID, completed_slurm_job
-from test.testdoubles.executor import (SlurmJobExecutorSpy,
-                                       successful_slurm_job_command_stub)
+from test.testdoubles.executor import (
+    SlurmJobExecutorSpy,
+    successful_slurm_job_command_stub,
+)
 from unittest.mock import Mock
 
 from hpcrocket.core.slurmcontroller import SlurmController
