@@ -13,6 +13,9 @@ class StageSpy:
         self.received_ui: UI = None  # type: ignore[assignment]
         self.run_callback: Callable[[], None] = lambda: None
 
+    def allowed_to_fail(self) -> bool:
+        return False
+
     def __call__(self, ui: UI) -> bool:
         self.was_run = True
         self.received_ui = ui
@@ -26,15 +29,18 @@ class StageSpy:
         return self.was_run
 
 
-def failing_stage() -> Stage:
-    class _Stage:
-        def __call__(self, ui: Optional[UI] = None) -> bool:
-            return False
+class FailingStage:
+    def __init__(self, allowed_to_fail: bool = False) -> None:
+        self._allowed_to_fail = allowed_to_fail
 
-        def cancel(self, ui: Optional[UI] = None) -> None:
-            pass
+    def allowed_to_fail(self) -> bool:
+        return self._allowed_to_fail
 
-    return _Stage()
+    def __call__(self, ui: Optional[UI] = None) -> bool:
+        return False
+
+    def cancel(self, ui: Optional[UI] = None) -> None:
+        pass
 
 
 def ui_dummy() -> Mock:
@@ -74,7 +80,7 @@ def test__given_workflow_with_stages__when_running__should_call_all_stages() ->
 
 
 def test__given_workflow_with_stage__when_stage_fails__should_return_false() -> None:
-    sut = make_sut([failing_stage()])
+    sut = make_sut([FailingStage()])
 
     actual = sut.run(ui_dummy())
 
@@ -83,7 +89,7 @@ def test__given_workflow_with_stage__when_stage_fails__should_return_false() ->
 
 def test__given_workflow_with_stages__when_first_stage_fails__should_not_call_second_stage() -> None:
     second_stage = StageSpy()
-    sut = make_sut([failing_stage(), second_stage])
+    sut = make_sut([FailingStage(), second_stage])
 
     sut.run(ui_dummy())
 
@@ -120,5 +126,15 @@ def test__given_running_workflow_with_two_stages__when_canceling_during_first_st
     assert second_stage.was_run is False
 
 
+def test__given_a_failing_stage_that_is_allowed_to_fail__when_running__executes_remaining_stages() -> None:
+    first_stage = FailingStage(allowed_to_fail=True)
+    second_stage = StageSpy()
+    sut = make_sut([first_stage, second_stage])
+
+    sut.run(ui_dummy())
+
+    assert second_stage.was_run is True
+
+
 def cancel_workflow(sut: Workflow) -> Callable[[], None]:
     return lambda: sut.cancel(ui_dummy())
